pub struct Incoming { /* private fields */ }Expand description
A stream of Bytes, used when receiving bodies from the network.
Note that Users should not instantiate this struct directly. When working with the client,
Incoming is returned to you in responses. Similarly, when operating with the server,
it is provided within requests.