Struct Codec

pub struct Codec<T, B> { /* private fields */ }
Available on crate feature unstable only.

Implementations

Source

impl<T, B> Codec<T, B>
where T: AsyncRead + AsyncWrite + Unpin, B: Buf,

pub fn new(io: T) -> Self

Returns a new Codec with the default max frame size

pub fn with_max_recv_frame_size(io: T, max_frame_size: usize) -> Self

Returns a new Codec with the given maximum frame size

Source

impl<T, B> Codec<T, B>

pub fn set_max_recv_frame_size(&mut self, val: usize)

Updates the max received frame size.

The change takes effect the next time a frame is decoded. In other words, if a frame is currently in process of being decoded with a frame size greater than val but less than the max frame size in effect before calling this function, then the frame will be allowed.

pub fn max_recv_frame_size(&self) -> usize

Returns the current max received frame size setting.

This is the largest size this codec will accept from the wire. Larger frames will be rejected.

pub fn max_send_frame_size(&self) -> usize

Returns the max frame size that can be sent to the peer.

pub fn set_max_send_frame_size(&mut self, val: usize)

Set the peer’s max frame size.

pub fn set_send_header_table_size(&mut self, val: usize)

Set the peer’s header table size size.

pub fn set_recv_header_table_size(&mut self, val: usize)

Set the decoder header table size size.

pub fn set_max_recv_header_list_size(&mut self, val: usize)

Set the max header list size that can be received.

pub fn get_ref(&self) -> &T

Get a reference to the inner stream.

pub fn get_mut(&mut self) -> &mut T

Get a mutable reference to the inner stream.

Source

impl<T, B> Codec<T, B>
where T: AsyncWrite + Unpin, B: Buf,

pub fn poll_ready(&mut self, cx: &mut Context<'_>) -> Poll<Result<()>>

Returns Ready when the codec can buffer a frame

pub fn buffer(&mut self, item: Frame<B>) -> Result<(), UserError>

Buffer a frame.

poll_ready must be called first to ensure that a frame may be accepted.

TODO: Rename this to avoid conflicts with Sink::buffer

pub fn flush(&mut self, cx: &mut Context<'_>) -> Poll<Result<()>>

Flush buffered data to the wire

pub fn shutdown(&mut self, cx: &mut Context<'_>) -> Poll<Result<()>>

Shutdown the send half