pub struct Http1Builder<'a> { /* private fields */ }Expand description
Http1 part of builder.
Implementations
Sourceimpl Http1Builder<'_>
impl Http1Builder<'_>
Sourcepub fn http2(&mut self) -> Http2Builder<'_>
pub fn http2(&mut self) -> Http2Builder<'_>
Http2 configuration.
Sourcepub fn auto_date_header(&mut self, enabled: bool) -> &mut Self
pub fn auto_date_header(&mut self, enabled: bool) -> &mut Self
Set whether the date header should be included in HTTP responses.
Note that including the date header is recommended by RFC 7231.
Default is true.
Sourcepub fn half_close(&mut self, val: bool) -> &mut Self
pub fn half_close(&mut self, val: bool) -> &mut Self
Set whether HTTP/1 connections should support half-closures.
Clients can chose to shutdown their write-side while waiting
for the server to respond. Setting this to true will
prevent closing the connection immediately if read
detects an EOF in the middle of a request.
Default is false.
Sourcepub fn keep_alive(&mut self, val: bool) -> &mut Self
pub fn keep_alive(&mut self, val: bool) -> &mut Self
Enables or disables HTTP/1 keep-alive.
Default is true.
Sourcepub fn title_case_headers(&mut self, enabled: bool) -> &mut Self
pub fn title_case_headers(&mut self, enabled: bool) -> &mut Self
Set whether HTTP/1 connections will write header names as title case at the socket level.
Note that this setting does not affect HTTP/2.
Default is false.
Sourcepub fn ignore_invalid_headers(&mut self, enabled: bool) -> &mut Self
pub fn ignore_invalid_headers(&mut self, enabled: bool) -> &mut Self
Set whether HTTP/1 connections will silently ignored malformed header lines.
If this is enabled and a header line does not start with a valid header name, or does not include a colon at all, the line will be silently ignored and no error will be reported.
Default is false.
Sourcepub fn max_headers(&mut self, val: usize) -> &mut Self
pub fn max_headers(&mut self, val: usize) -> &mut Self
Set the maximum number of headers.
When a request is received, the parser will reserve a buffer to store headers for optimal performance.
If server receives more headers than the buffer size, it responds to the client with “431 Request Header Fields Too Large”.
The headers is allocated on the stack by default, which has higher performance. After setting this value, headers will be allocated in heap memory, that is, heap memory allocation will occur for each request, and there will be a performance drop of about 5%.
Note that this setting does not affect HTTP/2.
Default is 100.
Sourcepub fn header_read_timeout(&mut self, read_timeout: Duration) -> &mut Self
pub fn header_read_timeout(&mut self, read_timeout: Duration) -> &mut Self
Set a timeout for reading client request headers. If a client does not transmit the entire header within this time, the connection is closed.
Default is currently 30 seconds, but do not depend on that.
Sourcepub fn writev(&mut self, val: bool) -> &mut Self
pub fn writev(&mut self, val: bool) -> &mut Self
Set whether HTTP/1 connections should try to use vectored writes, or always flatten into a single buffer.
Note that setting this to false may mean more copies of body data, but may also improve performance when an IO transport doesn’t support vectored writes well, such as most TLS implementations.
Setting this to true will force hyper to use queued strategy which may eliminate unnecessary cloning on some TLS backends
Default is auto. In this mode rama-http-core will try to guess which
mode to use
Sourcepub fn max_buf_size(&mut self, max: usize) -> &mut Self
pub fn max_buf_size(&mut self, max: usize) -> &mut Self
Set the maximum buffer size for the connection.
Default is ~400kb.
Panics
The minimum value allowed is 8192. This method panics if the passed max is less than the minimum.
Sourcepub fn pipeline_flush(&mut self, enabled: bool) -> &mut Self
pub fn pipeline_flush(&mut self, enabled: bool) -> &mut Self
Aggregates flushes to better support pipelined responses.
Experimental, may have bugs.
Default is false.
Sourcepub async fn serve_connection<I, S>(
&self,
io: I,
service: S,
) -> Result<(), BoxError>
pub async fn serve_connection<I, S>( &self, io: I, service: S, ) -> Result<(), BoxError>
Bind a connection together with a [Service].
Sourcepub fn serve_connection_with_upgrades<I, S>(
&self,
io: I,
service: S,
) -> UpgradeableConnection<'_, I, S> ⓘ
pub fn serve_connection_with_upgrades<I, S>( &self, io: I, service: S, ) -> UpgradeableConnection<'_, I, S> ⓘ
Bind a connection together with a [Service], with the ability to
handle HTTP upgrades. This requires that the IO object implements
Send.